@@ -93,12 +93,12 @@ func (m *MetricsServer) checkAccess(ns, gvr, msg string) error {
 		return errors.New("no metrics-server detected on cluster")
 	}
 
-	auth, err := m.CanI(ns, gvr, ListAccess)
+	auth, err := m.CanI(ns, gvr, "", ListAccess)
 	if err != nil {
 		return err
 	}
 	if !auth {
-		return fmt.Errorf(msg)
+		return errors.New(msg)
 	}
 	return nil
 }
