@@ -4,6 +4,7 @@
 package data
 
 import (
+	"os"
 	"sync"
 
 	"github.com/derailed/k9s/internal/client"
@@ -52,9 +53,12 @@ func NewContextFromKubeConfig(ks KubeSettings) (*Context, error) {
 }
 
 func (c *Context) merge(old *Context) {
-	if old == nil {
+	if old == nil || old.Namespace == nil {
 		return
 	}
+	if c.Namespace == nil {
+		c.Namespace = NewNamespace()
+	}
 	c.Namespace.merge(old.Namespace)
 }
 
@@ -70,12 +74,18 @@ func (c *Context) Validate(conn client.Connection, ks KubeSettings) {
 	c.mx.Lock()
 	defer c.mx.Unlock()
 
+	if a := os.Getenv(envPFAddress); a != "" {
+		c.PortForwardAddress = a
+	}
 	if c.PortForwardAddress == "" {
 		c.PortForwardAddress = defaultPFAddress()
 	}
 	if cl, err := ks.CurrentClusterName(); err == nil {
 		c.ClusterName = cl
 	}
+	if b := os.Getenv(envFGNodeShell); b != "" {
+		c.FeatureGates.NodeShell = defaultFGNodeShell()
+	}
 
 	if c.Namespace == nil {
 		c.Namespace = NewNamespace()
