@@ -6,6 +6,7 @@ package dao
 import (
 	"context"
 	"fmt"
+	"strconv"
 
 	"github.com/derailed/k9s/internal"
 	"github.com/derailed/k9s/internal/client"
@@ -22,6 +23,12 @@ var (
 	_ Loggable = (*Container)(nil)
 )
 
+const (
+	initIDX = "I"
+	mainIDX = "M"
+	ephIDX  = "E"
+)
+
 // Container represents a pod's container dao.
 type Container struct {
 	NonResource
@@ -46,12 +53,15 @@ func (c *Container) List(ctx context.Context, _ string) ([]runtime.Object, error
 	if err != nil {
 		return nil, err
 	}
-	res := make([]runtime.Object, 0, len(po.Spec.InitContainers)+len(po.Spec.Containers))
-	for _, co := range po.Spec.InitContainers {
-		res = append(res, makeContainerRes(co, po, cmx[co.Name], true))
+	res := make([]runtime.Object, 0, len(po.Spec.InitContainers)+len(po.Spec.Containers)+len(po.Spec.EphemeralContainers))
+	for i, co := range po.Spec.InitContainers {
+		res = append(res, makeContainerRes(initIDX, i, co, po, cmx[co.Name]))
 	}
-	for _, co := range po.Spec.Containers {
-		res = append(res, makeContainerRes(co, po, cmx[co.Name], false))
+	for i, co := range po.Spec.Containers {
+		res = append(res, makeContainerRes(mainIDX, i, co, po, cmx[co.Name]))
+	}
+	for i, co := range po.Spec.EphemeralContainers {
+		res = append(res, makeContainerRes(ephIDX, i, v1.Container(co.EphemeralContainerCommon), po, cmx[co.Name]))
 	}
 
 	return res, nil
@@ -68,25 +78,29 @@ func (c *Container) TailLogs(ctx context.Context, opts *LogOptions) ([]LogChan,
 // ----------------------------------------------------------------------------
 // Helpers...
 
-func makeContainerRes(co v1.Container, po *v1.Pod, cmx *mv1beta1.ContainerMetrics, isInit bool) render.ContainerRes {
+func makeContainerRes(kind string, idx int, co v1.Container, po *v1.Pod, cmx *mv1beta1.ContainerMetrics) render.ContainerRes {
 	return render.ContainerRes{
+		Idx:       kind + strconv.Itoa(idx+1),
 		Container: &co,
-		Status:    getContainerStatus(co.Name, po.Status),
+		Status:    getContainerStatus(kind, idx, po.Status),
 		MX:        cmx,
-		IsInit:    isInit,
 		Age:       po.GetCreationTimestamp(),
 	}
 }
 
-func getContainerStatus(co string, status v1.PodStatus) *v1.ContainerStatus {
-	for _, c := range status.ContainerStatuses {
-		if c.Name == co {
-			return &c
+func getContainerStatus(kind string, idx int, status v1.PodStatus) *v1.ContainerStatus {
+	switch kind {
+	case mainIDX:
+		if idx < len(status.ContainerStatuses) {
+			return &status.ContainerStatuses[idx]
 		}
-	}
-	for _, c := range status.InitContainerStatuses {
-		if c.Name == co {
-			return &c
+	case initIDX:
+		if idx < len(status.InitContainerStatuses) {
+			return &status.InitContainerStatuses[idx]
+		}
+	case ephIDX:
+		if idx < len(status.EphemeralContainerStatuses) {
+			return &status.EphemeralContainerStatuses[idx]
 		}
 	}
 
@@ -94,7 +108,7 @@ func getContainerStatus(co string, status v1.PodStatus) *v1.ContainerStatus {
 }
 
 func (c *Container) fetchPod(fqn string) (*v1.Pod, error) {
-	o, err := c.GetFactory().Get("v1/pods", fqn, true, labels.Everything())
+	o, err := c.getFactory().Get("v1/pods", fqn, true, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
