@@ -167,19 +167,22 @@ func (t *TableData) rxFilter(q string, inverse bool) (*RowEvents, error) {
 		return nil, fmt.Errorf("invalid rx filter %q: %w", q, err)
 	}
 
-	ageIndex, ok := t.header.IndexOf("AGE", true)
-
-	rr := NewRowEvents(t.RowCount() / 2)
+	var startIndex int
+	if _, ok := t.header.IndexOf("NAMESPACE", true); ok && client.IsNamespaced(t.namespace) {
+		startIndex = 1
+	}
+	rr := NewRowEvents(50)
+	ageIndex, _ := t.header.IndexOf("AGE", true)
 	t.rowEvents.Range(func(_ int, re RowEvent) bool {
-		ff := re.Row.Fields
-		if ok && ageIndex+1 <= len(ff) {
+		ff := re.Row.Fields[startIndex:]
+		if ageIndex >= 0 && ageIndex+1 <= len(ff) {
 			ff = append(ff[0:ageIndex], ff[ageIndex+1:]...)
 		}
-		fields := strings.Join(ff, spacer)
-		if (inverse && !rx.MatchString(fields)) ||
-			((!inverse) && rx.MatchString(fields)) {
+		match := rx.MatchString(strings.Join(ff, spacer))
+		if (inverse && !match) || (!inverse && match) {
 			rr.Add(re)
 		}
+
 		return true
 	})
 
@@ -244,7 +247,6 @@ func (t *TableData) Reset(ns string) {
 
 func (t *TableData) Reconcile(ctx context.Context, r Renderer, oo []runtime.Object) error {
 	var rows Rows
-
 	if len(oo) > 0 {
 		if r.IsGeneric() {
 			table, ok := oo[0].(*metav1.Table)
@@ -399,6 +401,7 @@ func (t *TableData) Clone() *TableData {
 		header:    t.header.Clone(),
 		rowEvents: t.rowEvents.Clone(),
 		namespace: t.namespace,
+		gvr:       t.gvr,
 	}
 }
 
