@@ -8,6 +8,7 @@ import (
 	"strings"
 
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/model1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 )
@@ -18,17 +19,17 @@ type Alias struct {
 }
 
 // Header returns a header row.
-func (Alias) Header(ns string) Header {
-	return Header{
-		HeaderColumn{Name: "RESOURCE"},
-		HeaderColumn{Name: "COMMAND"},
-		HeaderColumn{Name: "API-GROUP"},
+func (Alias) Header(ns string) model1.Header {
+	return model1.Header{
+		model1.HeaderColumn{Name: "RESOURCE"},
+		model1.HeaderColumn{Name: "COMMAND"},
+		model1.HeaderColumn{Name: "API-GROUP"},
 	}
 }
 
 // Render renders a K8s resource to screen.
 // BOZO!! Pass in a row with pre-alloc fields??
-func (Alias) Render(o interface{}, ns string, r *Row) error {
+func (Alias) Render(o interface{}, ns string, r *model1.Row) error {
 	a, ok := o.(AliasRes)
 	if !ok {
 		return fmt.Errorf("expected AliasRes, but got %T", o)
