@@ -295,16 +295,77 @@ func Test_restartableInitCO(t *testing.T) {
 	}
 }
 
+func Test_filterSidecarCO(t *testing.T) {
+	always := v1.ContainerRestartPolicyAlways
+
+	uu := map[string]struct {
+		cc, ecc []v1.Container
+	}{
+		"empty": {
+			cc:  []v1.Container{},
+			ecc: []v1.Container{},
+		},
+		"restartable": {
+			cc: []v1.Container{
+				{
+					Name:          "c1",
+					RestartPolicy: &always,
+				},
+			},
+			ecc: []v1.Container{
+				{
+					Name:          "c1",
+					RestartPolicy: &always,
+				},
+			},
+		},
+		"not-restartable": {
+			cc: []v1.Container{
+				{
+					Name: "c1",
+				},
+			},
+			ecc: []v1.Container{},
+		},
+		"mixed": {
+			cc: []v1.Container{
+				{
+					Name: "c1",
+				},
+				{
+					Name:          "c2",
+					RestartPolicy: &always,
+				},
+			},
+			ecc: []v1.Container{
+				{
+					Name:          "c2",
+					RestartPolicy: &always,
+				},
+			},
+		},
+	}
+
+	for k := range uu {
+		u := uu[k]
+		t.Run(k, func(t *testing.T) {
+			assert.Equal(t, u.ecc, filterSidecarCO(u.cc))
+		})
+	}
+}
+
 func Test_gatherPodMx(t *testing.T) {
 	uu := map[string]struct {
-		cc   []v1.Container
+		spec *v1.PodSpec
 		mx   []mv1beta1.ContainerMetrics
 		c, r metric
 		perc string
 	}{
 		"single": {
-			cc: []v1.Container{
-				makeContainer("c1", false, "10m", "1Mi", "20m", "2Mi"),
+			spec: &v1.PodSpec{
+				Containers: []v1.Container{
+					makeContainer("c1", false, "10m", "1Mi", "20m", "2Mi"),
+				},
 			},
 			mx: []mv1beta1.ContainerMetrics{
 				makeCoMX("c1", "1m", "22Mi"),
@@ -322,10 +383,12 @@ func Test_gatherPodMx(t *testing.T) {
 			perc: "10",
 		},
 		"multi": {
-			cc: []v1.Container{
-				makeContainer("c1", false, "11m", "22Mi", "111m", "44Mi"),
-				makeContainer("c2", false, "93m", "1402Mi", "0m", "2804Mi"),
-				makeContainer("c3", false, "11m", "34Mi", "0m", "69Mi"),
+			spec: &v1.PodSpec{
+				Containers: []v1.Container{
+					makeContainer("c1", false, "11m", "22Mi", "111m", "44Mi"),
+					makeContainer("c2", false, "93m", "1402Mi", "0m", "2804Mi"),
+					makeContainer("c3", false, "11m", "34Mi", "0m", "69Mi"),
+				},
 			},
 			r: metric{
 				cpu:  11 + 93 + 11,
@@ -344,12 +407,37 @@ func Test_gatherPodMx(t *testing.T) {
 			},
 			perc: "46",
 		},
+		"sidecar": {
+			spec: &v1.PodSpec{
+				Containers: []v1.Container{
+					makeContainer("c1", false, "11m", "22Mi", "111m", "44Mi"),
+				},
+				InitContainers: []v1.Container{
+					makeContainer("c2", true, "93m", "1402Mi", "0m", "2804Mi"),
+				},
+			},
+			r: metric{
+				cpu:  11 + 93,
+				mem:  (22 + 1402) * client.MegaByte,
+				lcpu: 111 + 0,
+				lmem: (44 + 2804) * client.MegaByte,
+			},
+			mx: []mv1beta1.ContainerMetrics{
+				makeCoMX("c1", "1m", "22Mi"),
+				makeCoMX("c2", "51m", "1275Mi"),
+			},
+			c: metric{
+				cpu: 1 + 51,
+				mem: (22 + 1275) * client.MegaByte,
+			},
+			perc: "50",
+		},
 	}
 
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			c, r := gatherCoMX(u.cc, u.mx)
+			c, r := gatherCoMX(u.spec, u.mx)
 			assert.Equal(t, u.c.cpu, c.cpu)
 			assert.Equal(t, u.c.mem, c.mem)
 			assert.Equal(t, u.c.lcpu, c.lcpu)
@@ -427,18 +515,19 @@ func Test_podRequests(t *testing.T) {
 
 // Helpers...
 
-func makeContainer(n string, init bool, rc, rm, lc, lm string) v1.Container {
+func makeContainer(n string, restartable bool, rc, rm, lc, lm string) v1.Container {
+	always := v1.ContainerRestartPolicyAlways
 	var res v1.ResourceRequirements
-	if init {
-		res = v1.ResourceRequirements{}
-	} else {
-		res = v1.ResourceRequirements{
-			Requests: makeRes(rc, rm),
-			Limits:   makeRes(lc, lm),
-		}
+	var rp *v1.ContainerRestartPolicy
+	res = v1.ResourceRequirements{
+		Requests: makeRes(rc, rm),
+		Limits:   makeRes(lc, lm),
+	}
+	if restartable {
+		rp = &always
 	}
 
-	return v1.Container{Name: n, Resources: res}
+	return v1.Container{Name: n, Resources: res, RestartPolicy: rp}
 }
 
 func makeRes(c, m string) v1.ResourceList {
