@@ -206,7 +206,13 @@ func pluginAction(r Runner, p config.Plugin) ui.ActionHandler {
 			}
 			go func() {
 				for st := range statusChan {
-					r.App().Flash().Infof("Plugin command launched successfully: %q", st)
+					if !p.OverwriteOutput {
+						r.App().Flash().Infof("Plugin command launched successfully: %q", st)
+					} else if strings.Contains(st, outputPrefix) {
+						infoMsg := strings.TrimPrefix(st, outputPrefix)
+						r.App().Flash().Info(strings.TrimSpace(infoMsg))
+						return
+					}
 				}
 			}()
 
