@@ -160,14 +160,6 @@ func (c *Command) run(p *cmd.Interpreter, fqn string, clearStack bool) error {
 		return err
 	}
 
-	ns := c.app.Config.ActiveNamespace()
-	if cns, ok := p.NSArg(); ok {
-		ns = cns
-	}
-	if err := c.app.switchNS(ns); err != nil {
-		return err
-	}
-
 	if context, ok := p.HasContext(); ok {
 		if context != c.app.Config.ActiveContextName() {
 			if err := c.app.Config.Save(true); err != nil {
@@ -193,6 +185,14 @@ func (c *Command) run(p *cmd.Interpreter, fqn string, clearStack bool) error {
 		}
 	}
 
+	ns := c.app.Config.ActiveNamespace()
+	if cns, ok := p.NSArg(); ok {
+		ns = cns
+	}
+	if err := c.app.switchNS(ns); err != nil {
+		return err
+	}
+
 	co := c.componentFor(gvr, fqn, v)
 	co.SetFilter("")
 	co.SetLabelFilter(nil)
@@ -286,7 +286,11 @@ func (c *Command) viewMetaFor(p *cmd.Interpreter) (client.GVR, *MetaViewer, erro
 		p.Amend(ap)
 	}
 
-	v := MetaViewer{viewerFn: NewBrowser}
+	v := MetaViewer{
+		viewerFn: func(gvr client.GVR) ResourceViewer {
+			return NewOwnerExtender(NewBrowser(gvr))
+		},
+	}
 	if mv, ok := customViewers[gvr]; ok {
 		v = mv
 	}
