@@ -26,9 +26,9 @@ func NewGroup(gvr client.GVR) ResourceViewer {
 	return &g
 }
 
-func (g *Group) bindKeys(aa ui.KeyActions) {
+func (g *Group) bindKeys(aa *ui.KeyActions) {
 	aa.Delete(ui.KeyShiftA, ui.KeyShiftP, tcell.KeyCtrlSpace, ui.KeySpace)
-	aa.Add(ui.KeyActions{
+	aa.Bulk(ui.KeyMap{
 		tcell.KeyEnter: ui.NewKeyAction("Rules", g.policyCmd, true),
 		ui.KeyShiftK:   ui.NewKeyAction("Sort Kind", g.GetTable().SortColCmd("KIND", true), false),
 	})
